# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class VatAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status', 'code',),
        ('name__icontains',),
        ('aliquot_perc__gte', 'aliquot_perc__lte',),
        ('deduct_perc__gte', 'deduct_perc__lte',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('name', 'slug', 'code', 'description',)
        }),
        (_('aliq admin'), {
            'fields': ('aliquot_perc', 'deduct_perc',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'code', 'status', 'name', 'slug',
        'aliquot_perc', 'deduct_perc', 'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {"slug": ("name",)}


admin.site.register(models.Vat, VatAdmin)
