# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # VAT
    def v1_vat_vat_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_vat_vat_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_vat_vat_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_vat_vat_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_vat_vat_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_vat_vat_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_vat_vat_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_vat_vat_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_vat_vat_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-vat:vat-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
