# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)


# VAT
class VatSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat'
        model = models.Vat
        fields = '__all__'


class VatListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_list'
        model = models.Vat
        fields = ("code", "name", "slug", "description", "aliquot_perc", "deduct_perc", "status", "ordering")

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class VatRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_retrieve'
        model = models.Vat
        fields = ("code", "name", "slug", "description", "aliquot_perc", "deduct_perc", "status", "ordering")

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class VatCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_create'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return VatListSerializer(instance, context=self.context).data


class VatUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_update'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return VatRetrieveSerializer(instance, context=self.context).data


class VatPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_partial_update'
        model = models.Vat
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return VatRetrieveSerializer(instance, context=self.context).data


class VatEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_enable'
        model = models.Vat
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return VatRetrieveSerializer(instance, context=self.context).data


class VatDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_disable'
        model = models.Vat
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return VatRetrieveSerializer(instance, context=self.context).data


class VatLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat_light'
        model = models.Vat
        fields = ('code', 'status', 'get_status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
