# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import gettext_lazy as _
from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel


class Vat(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        primary_key=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_("slug"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    aliquot_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("aliquot perc"),
    )
    deduct_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("deduct perc"),
    )

    class Meta:
        verbose_name = _('VAT rate')
        verbose_name_plural = _('VAT rates')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_vat", "Can list vat"),
            ("detail_vat", "Can detail vat"),
            ("enable_vat", "Can enable vat"),
            ("disable_vat", "Can disable vat"),
        )

    def __str__(self):
        return self.name
